﻿''''''''''''''''''''''''''''''''''
' Author - Nasri 2022 dzosoft.com
'''''''''''''''''''''''''''''''''''

Imports System.ComponentModel
Imports System.Xml
Imports System.Xml.Serialization
Imports System.IO

'<Serializable()>

Public Class AppSettings : Implements ISettings
    Protected _size As System.Drawing.Size
    Dim _ApplicationFont As Font
    Dim _ApplicationBackColor As Color = New Color()
    Dim _ApplicationForeColor As Color = New Color()
    Dim _MenuBackColor As Color = New Color()
    Dim _MenuForeColor As Color = New Color()
    Dim _title As String
    Dim _show As Boolean
    Dim _number As Short

    <Category("Application"),
       Browsable(True),
       [ReadOnly](False),
       Bindable(False),
       DefaultValue(""),
       DesignOnly(False),
       Description("Enter Title for the application")>
    Public Property Title() As String
        Get
            Return _title
        End Get
        Set(ByVal value As String)
            _title = value
        End Set
    End Property
    <Category("Application"),
    Browsable(True),
    [ReadOnly](False),
    Bindable(False),
    DefaultValue("True"),
    DesignOnly(False),
    Description("Show option")>
    Public Property Show() As Boolean
        Get
            Return _show
        End Get
        Set(value As Boolean)
            _show = value
        End Set
    End Property

    <Category("Application Font"),
       Browsable(True),
       [ReadOnly](False),
       Bindable(False),
       DefaultValue(""),
       DesignOnly(False),
       Description("Enter the font")>
    Public Property ApplicationFont() As System.Drawing.Font
        Get
            Return _ApplicationFont
        End Get
        Set(ByVal Value As System.Drawing.Font)
            _ApplicationFont = Value
        End Set
    End Property

    <Category("Application Color"),
       Browsable(True),
       [ReadOnly](False),
       Bindable(False),
       DefaultValue(""),
       DesignOnly(False),
       Description("Enter the color")>
    Public Property WindowSize() As System.Drawing.Size
        Get
            Return _size
        End Get
        Set(ByVal value As System.Drawing.Size)
            _size = value
        End Set
    End Property
    Public Property ApplicationBackColor() As Color
        Get
            Return _ApplicationBackColor
        End Get
        Set(ByVal Value As Color)
            _ApplicationBackColor = Value
        End Set
    End Property
    <Category("Application Color"),
       Browsable(True),
       [ReadOnly](False),
       Bindable(False),
       DefaultValue(""),
       DesignOnly(False),
       Description("Enter the color")>
    Public Property ApplicationForeColor() As Color
        Get
            Return _ApplicationForeColor
        End Get
        Set(ByVal Value As Color)
            _ApplicationForeColor = Value
        End Set
    End Property

    <Category("Menu Color"),
       Browsable(True),
       [ReadOnly](False),
       Bindable(False),
       DefaultValue("White"),
       DesignOnly(False),
       Description("Enter the color")>
    Public Property MenuBackColor() As Color
        Get
            Return _MenuBackColor
        End Get
        Set(ByVal Value As Color)
            _MenuBackColor = Value
        End Set
    End Property
    <Category("Menu Color"),
       Browsable(True),
       [ReadOnly](False),
       Bindable(False),
       DefaultValue("Black"),
       DesignOnly(False),
       Description("Enter the color")>
    Public Property MenuForeColor() As Color
        Get
            Return _MenuForeColor
        End Get
        Set(ByVal Value As Color)
            _MenuForeColor = Value
        End Set
    End Property
    Public Sub Load() Implements ISettings.Load
        Dim reader As TextReader
        Dim fileNotFound As Boolean
        Dim fontName As String = ""

        Try
            reader = New StreamReader(Principal.xmlAppSetting)
        Catch ex As FileNotFoundException
            ' Take the defaults
            fileNotFound = True
        End Try

        If fileNotFound Then
            WindowSize = New System.Drawing.Size(308, 774)
            _ApplicationBackColor = Color.CadetBlue
            _ApplicationForeColor = Color.Black
            _MenuBackColor = Color.Black
            _MenuForeColor = Color.White
            _ApplicationFont = New Font("Arial", 8)
        Else
            Dim xr As XmlReader = XmlReader.Create(Principal.xmlAppSetting)
            Do While xr.Read()
                Dim read As Boolean = False

                If (xr.NodeType = XmlNodeType.Element) Then

                    If xr.NodeType = XmlNodeType.Element AndAlso xr.Name = "Title" Then
                        Title = xr.ReadElementString()
                        read = True
                    End If
                    If xr.NodeType = XmlNodeType.Element AndAlso xr.Name = "Show" Then
                        Show = xr.ReadElementString()
                        read = True
                    End If
                    If xr.NodeType = XmlNodeType.Element AndAlso xr.Name = "Size" Then
                        Dim s() As String
                        Dim s1 As Integer
                        Dim s2 As Integer
                        Dim svalue = xr.ReadElementString()
                        svalue = svalue.Replace("{", "")
                        svalue = svalue.Replace("}", "")
                        s = svalue.Split(",")
                        s1 = CInt(s(0).Substring(s(0).IndexOf("=") + 1))
                        s2 = CInt(s(1).Substring(s(1).IndexOf("=") + 1))
                        WindowSize = New Size(s1, s2)
                        read = True
                    End If
                    If xr.NodeType = XmlNodeType.Element AndAlso xr.Name = "FontName" Then
                        fontName = xr.ReadElementString()
                        read = True
                    End If
                    If xr.NodeType = XmlNodeType.Element AndAlso xr.Name = "FontSize" Then
                        If (fontName <> "") Then
                            ApplicationFont = New Font(fontName, CInt(xr.ReadElementString()))
                        End If
                        read = True
                    End If
                    If xr.NodeType = XmlNodeType.Element AndAlso xr.Name = "BackColor" Then
                        Dim svalue = xr.ReadElementString()
                        ApplicationBackColor = Color.FromArgb(CInt(svalue))
                        read = True
                    End If
                    If xr.NodeType = XmlNodeType.Element AndAlso xr.Name = "ForeColor" Then
                        Dim svalue = xr.ReadElementString()
                        ApplicationForeColor = Color.FromArgb(CInt(svalue))
                        read = True
                    End If
                    If xr.NodeType = XmlNodeType.Element AndAlso xr.Name = "MenuBackColor" Then
                        Dim svalue = xr.ReadElementString()
                        MenuBackColor = Color.FromArgb(CInt(svalue))
                        read = True
                    End If
                    If xr.NodeType = XmlNodeType.Element AndAlso xr.Name = "MenuForeColor" Then
                        Dim svalue = xr.ReadElementString()
                        MenuForeColor = Color.FromArgb(CInt(svalue))
                        read = True
                    End If
                    If (Not read) Then
                        xr.Read()
                    End If

                Else

                    xr.Read()
                End If
            Loop

            xr.Close()
            reader.Close()
        End If
    End Sub

    Public Sub SaveSetting(_xmlAppSetting As String) Implements ISettings.SaveSetting
        Dim xws As XmlWriterSettings = New XmlWriterSettings()
        xws.Indent = True
        xws.NewLineOnAttributes = True
        Dim xw As XmlWriter = XmlWriter.Create(_xmlAppSetting, xws)
        xw.WriteStartDocument()
        xw.WriteStartElement("Settings")
        xw.WriteElementString("Title", Title)
        xw.WriteElementString("Show", Show)
        xw.WriteElementString("Size", WindowSize.ToString)
        If Not ApplicationFont Is Nothing Then
            xw.WriteElementString("FontName", ApplicationFont.Name)
            xw.WriteElementString("FontSize", ApplicationFont.Size)
        End If
        xw.WriteElementString("BackColor", ApplicationBackColor.ToArgb().ToString())
        xw.WriteElementString("ForeColor", ApplicationForeColor.ToArgb().ToString())
        xw.WriteElementString("MenuBackColor", MenuBackColor.ToArgb().ToString())
        xw.WriteElementString("MenuForeColor", MenuForeColor.ToArgb().ToString())
        xw.WriteEndElement()
        xw.WriteEndDocument()
        xw.Flush()
        xw.Close()
    End Sub

    Public Sub SaveSetting(ByRef obj As ptObject) Implements ISettings.SaveSetting
    End Sub
    Public Sub Load(obj As ptObject) Implements ISettings.Load
    End Sub
    Public Function getCountProperties() Implements ISettings.getCountProperties
        Return 8
    End Function
End Class